#!/usr/bin/env python3


from libervia.server.constants import Const as C
from twisted.words.protocols.jabber import jid
from sat.core.log import getLogger

log = getLogger(__name__)

name = "lists_disco"
access = C.PAGES_ACCESS_PUBLIC
template = "list/discover.html"


def prepare_render(self, request):
    lists_directory_config = self.host.options["lists_directory_json"]
    if lists_directory_config:
        trackers = request.template_data["lists_directory"] = []
        try:
            for tracker_data in lists_directory_config:
                service = tracker_data["service"]
                node = tracker_data["node"]
                name = tracker_data["name"]
                url = self.getPageByName("lists").getURL(service, node)
                trackers.append({"name": name, "url": url})
        except KeyError as e:
            log.warning("Missing field in lists_directory_json: {msg}".format(msg=e))
        except Exception as e:
            log.warning("Can't decode lists directory: {msg}".format(msg=e))


def on_data_post(self, request):
    jid_str = self.getPostedData(request, "jid")
    try:
        jid_ = jid.JID(jid_str)
    except RuntimeError:
        self.pageError(request, C.HTTP_BAD_REQUEST)
    # for now we just use default node
    url = self.getPageByName("lists").getURL(jid_.full(), "@")
    self.HTTPRedirect(request, url)
